# README #

### IQsubmit ###

* IQsubmit submits many similar task to a SLURM controller.
* Version: Alpha0

### Installation ###

* Place IQsubmit.py in a directory of your system's environement variable PYTHONPATH.
* Place IQsubmit in a directory of your system's environement variable PATH.
* Make sure the script IQsubmit has execution permission for your group.
* Dependency: python 3.x

On the Cedar and Graham supercomputer you have to add python3 to your  module list by executing the following commands:
    module add python/3.x
    module save


### Usage ###

For a given set of tasks, write a submit.iq file describing the ressources needs for the tasks
and how to adjust the configurations for each tasks. Semi-colons (';') and pound symbol ('#') in the configuration file marks
the begining of comments

A lenghtier (and working) exemple is available in exemple/ex1.

A simple exemple:

    [sbatch options]
    ## option forwarded to sbatch
    ## only --wrap is not supported
	## two tasks, with label 1 and 2
    --array=1,2
    --account=<your_project_account>
    --time=00:01:00
    --job-name=IQtest
	## amount of memory needed
	--mem=50MB
	## number of core per task
	--cpus-per-task=1
    
    [command]
    ## following is the command that will be executed by each task.
    command= echo hello from \${SLURM_ARRAY_JOB_ID}_\${SLURM_ARRAY_TASK_ID}>>out
    ## The template files will be manipulated by the substitution rules
    #template = para.dat
    ## files to copy
    #copyfiles =
    ## files to link
    #linkfiles =


    ## 'substitute' keyword can use %u, %x and %<optional value>a to do substitution according to the same rules as slurm
    ## for all substitution rules, the key is matched to ~key~ in the template file.
    #substitute = uname='my username is %u',jobname='the job name is %x', ind='array index is %a'
    
    ## Use the content of a file as substitution rules. The first line is the list of keys.
    #file_substitute = sub_list.dat
    
    ## range substitution. As many step as there are jobs are taken to do the range specified in paranthesis.
    #list_substitute = M(1:5)tpp(3:4)
    
    [loop]
    ## generate a file named loop.dat for each of your jobs. The step are split as evenly as possible among all the jobs
    ## the first line of the file is a header. Each of the name are specified before the range which they will have
    ## the number of step to do is at the end after colons. The data is tab separated.
    loop=mu(1:2)U(5:8):20
    ## you can also have a pre written loop file split amongst your jobs. assume the first line is a
    ## header, to be copied to every destination.
    #loop_file=loop.dat

Once your configuration file is ready call the script IQsubmit. You can execute the script without submiting by calling `IQsubmit -x`
For more option on the command line call `IQsubmit -h`

### Example ###

An example is available in the directory example/ex1.
You can execute it using the command line "IQsubmit" or "IQsubmit -x"
A copy of the output for the first case is in the subdirectory "expected" and in "expectedMX" for the second.
In the folders of expected results you find the folders,files and symbolic links IQsubmit creates and the console output in the text file stdout.txt
If you submit the test task to the slurm controller (by executing "IQsubmit") , you will find a text file named "out" containing a hello world in each of the jobs folders.
If you do not find any "out" file, it is perhaps because the task didn't run yet. Type:

$ squeue -n IQtest
on Graham to check if the task is done or not.


### Contributions and Suggestions ###

Your contributions, bug report and suggestions are welcome.
Submit them at https://bitbucket.org/alexandre_foley/graham-batch-submit

### Author ###

Alexandre Foley, PhD student at université de Sherbrooke.

Copyright (C) 2017  Alexandre Foley <Alexandre.Foley@usherbrooke.ca>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.


#########
Reviewer: Maxime Charlebois
Date: 19th december 2017
Tested on Graham

www.physique.usherbrooke.ca/source_code
code submission procedure v1.2 compliant


